@@ -4,11 +4,12 @@ use crate::datagram::DatagramHeader;
 use crate::{Addr, ETP};
 use core::time::Duration;
 use futures_intrusive::channel::shared::*;
+use futures_intrusive::sync::GenericMutex;
 use futures_util::{
     future::{select, Either},
     pin_mut,
 };
-use spin::Mutex;
+use spin::Lazy;
 cfg_if::cfg_if! {
     if #[cfg(feature = "role_center")] {
         use alloc::collections::BTreeMap;
@@ -18,11 +19,12 @@ cfg_if::cfg_if! {
         type BTreeMap<K, V> = LinearMap<K, V, RETRY_DATA_LEN>;
     }
 }
+type Mutex<T> = GenericMutex<spin::Mutex<()>, T>;
 
 /// 等待远程设备回复
-type WaitRepSender = GenericOneshotSender<Mutex<()>, ()>;
+type WaitRepSender = GenericOneshotSender<spin::Mutex<()>, ()>;
 struct WaitRepFuture {
-    recver: GenericOneshotReceiver<Mutex<()>, ()>,
+    recver: GenericOneshotReceiver<spin::Mutex<()>, ()>,
 }
 impl WaitRepFuture {
     pub fn new() -> (WaitRepFuture, WaitRepSender) {
@@ -46,7 +48,8 @@ impl WaitRepFuture {
     }
 }
 
-static WAITLIST: Mutex<BTreeMap<u16, WaitRepSender>> = Mutex::new(BTreeMap::new());
+static WAITLIST: Lazy<Mutex<BTreeMap<u16, WaitRepSender>>> =
+    Lazy::new(|| Mutex::new(BTreeMap::new(), false));
 
 /// 发送数据到指定设备，失败时重试retry次，返回用时时间
 pub(crate) async fn send(
@@ -63,7 +66,7 @@ pub(crate) async fn send(
 
     for _i in 0..retry + 1 {
         let (future, sender) = WaitRepFuture::new();
-        WAITLIST.lock().insert(index, sender); // TODO: use async lock
+        WAITLIST.lock().await.insert(index, sender);
         let etp = ETP.get().unwrap();
         let _err = etp.send(&buf, dst.conn()).await;
         if let Ok(consum) = future.wait(Duration::from_millis(timeout)).await {
@@ -76,8 +79,8 @@ pub(crate) async fn send(
 }
 
 /// 收到响应数据
-pub(crate) fn finish(index: u16) {
-    if let Some(sender) = WAITLIST.lock().remove(&index) {
+pub(crate) async fn finish(index: u16) {
+    if let Some(sender) = WAITLIST.lock().await.remove(&index) {
         let _err = sender.send(());
     }
 }
